==> web2ldap-0.15.10.tar.gz: web2ldap-0.15.10/pylib/w2lapp/core.py <==
"""
w2lapp.core.py: some core functions used throughout web2ldap

web2ldap - a web-based LDAP Client,
see http://www.web2ldap.de for details

(c) by Michael Stroeder <michael@stroeder.com>

This module is distributed under the terms of the
GPL (GNU GENERAL PUBLIC LICENSE) Version 2
(see http://www.gnu.org/copyleft/gpl.html)

$Id: core.py,v 1.70 2004/08/21 11:27:26 michael Exp $
"""

import sys,os,time,traceback,ldap,w2lapp.cnf

from pyweblib.forms import escapeHTML

from types import StringType,UnicodeType,ListType

def str2unicode(s,charset):
  if type(s) is StringType:
    try:
      return unicode(s,charset)
    except UnicodeError:
      return unicode(s,'iso-8859-1')
  else:
    return s

def utf2display(dispcharset,value,escape_entities=1):
  if type(value)==UnicodeType:
    unicode_value = value
  elif type(value) is StringType:
    if value.startswith('{T.61}'):
      unicode_value = unicode(value[6:],'iso-8859-1')
    else:
      try:
        unicode_value = unicode(value,'utf-8')
      except UnicodeError:
        unicode_value = unicode(value,'iso-8859-1')
  elif value is None:
    return ''
  elif type(value) is ListType:
    return [
      utf2display(dispcharset,i,escape_entities)
      for i in value
    ]
  else:
    raise TypeError, "expected string or list"
  if escape_entities:
    return escapeHTML(unicode_value.encode(dispcharset,'replace'))
  else:
    return unicode_value.encode(dispcharset,'replace')


def guessClientAddr(env=None):
  """
  Guesses the host name or IP address of the HTTP client by looking
  at various HTTP headers mapped to CGI-BIN environment.

  env
        dictionary containing environment vars (default os.env)
  """
  env = env or os.environ
  return env.get('FORWARDED_FOR',
         env.get('HTTP_X_FORWARDED_FOR',
         env.get('REMOTE_HOST',
         env.get('REMOTE_ADDR',None))))


class ErrorExit:
  """Base class for web2ldap application exceptions"""

  def __init__(self,Msg):
    self.Msg = Msg
#    self.charset = form.accept_charset
    self.charset = 'utf-8'

  def html(self):
    return utf2display(self.charset,self.Msg,escape_entities=1)


def log_exception(errf,ls,env):
  """
  Write an exception with environment vars, LDAP connection data
  and Python traceback to errf file object.
  """
  # Get exception instance and traceback info
  exc_obj,exc_value,exc_traceback = sys.exc_info()
  # Signals are raised again to trigger handling in main process
  if isinstance(exc_value,KeyboardInterrupt):
    raise
  if isinstance(exc_value,IOError) and (exc_value.errno==32):
    pass
  else:
    logentry = ['%s\nUnhandled error at %s' % (
        '-'*60,
        time.strftime(
          '%Y-%m-%dT%H:%M:%SZ',time.gmtime(time.time())
        ),
      )]
    logentry.append('LDAPSession instance: %s' % repr(ls))
    # Log all environment vars
    env_vars = env.keys();env_vars.sort()
    for v in env_vars:
      logentry.append('%s: "%s"' % (v,env[v]))
    logentry.append(''.join(traceback.format_exception(exc_obj,exc_value,exc_traceback,20)))
    # Write the log entry to errf file object
    errf.write(os.linesep.join(logentry))
  # Avoid memory leaks
  exc_obj=None;exc_value=None;exc_traceback=None
  del exc_obj;del exc_value;del exc_traceback


########################################################################
# Initialize some constants
########################################################################

ldap._trace_level=w2lapp.cnf.misc.ldap_trace_level
ldap.set_option(ldap.OPT_RESTART,0)
ldap.set_option(ldap.OPT_DEREF,0)
ldap.set_option(ldap.OPT_REFERRALS,0)

startUpTime = time.time()

==> web2ldap-0.16.12.tar.gz: web2ldap-0.16.12/pylib/w2lapp/core.py <==
"""
w2lapp.core.py: some core functions used throughout web2ldap

web2ldap - a web-based LDAP Client,
see http://www.web2ldap.de for details

(c) by Michael Stroeder <michael@stroeder.com>

This module is distributed under the terms of the
GPL (GNU GENERAL PUBLIC LICENSE) Version 2
(see http://www.gnu.org/copyleft/gpl.html)

$Id: core.py,v 1.75 2005/09/26 16:39:17 michael Exp $
"""

import sys,os,time,traceback,ldap,w2lapp.cnf

from pyweblib.forms import escapeHTML

from types import StringType,UnicodeType,ListType

def str2unicode(s,charset):
  if type(s) is StringType:
    try:
      return unicode(s,charset)
    except UnicodeError:
      return unicode(s,'iso-8859-1')
  else:
    return s

def utf2display(dispcharset,value,escape_entities=1):
  if type(value)==UnicodeType:
    unicode_value = value
  elif type(value) is StringType:
    if value.startswith('{T.61}'):
      unicode_value = unicode(value[6:],'iso-8859-1')
    else:
      try:
        unicode_value = unicode(value,'utf-8')
      except UnicodeError:
        unicode_value = unicode(value,'iso-8859-1')
  elif value is None:
    return ''
  else:
    raise TypeError, "expected String or Unicode object"
  if escape_entities:
    return escapeHTML(unicode_value.encode(dispcharset,'replace'))
  else:
    return unicode_value.encode(dispcharset,'replace')


def guessClientAddr(env=None):
  """
  Guesses the host name or IP address of the HTTP client by looking
  at various HTTP headers mapped to CGI-BIN environment.

  env
        dictionary containing environment vars (default os.env)
  """
  env = env or os.environ
  return env.get('FORWARDED_FOR',
         env.get('HTTP_X_FORWARDED_FOR',
         env.get('REMOTE_HOST',
         env.get('REMOTE_ADDR',None))))


class ErrorExit:
  """Base class for web2ldap application exceptions"""

  def __init__(self,Msg):
    self.Msg = Msg
#    self.charset = form.accept_charset
    self.charset = 'utf-8'

  def html(self):
    return utf2display(self.charset,self.Msg,escape_entities=1)


def log_exception(errf,ls,env):
  """
  Write an exception with environment vars, LDAP connection data
  and Python traceback to errf file object.
  """
  # Get exception instance and traceback info
  exc_obj,exc_value,exc_traceback = sys.exc_info()
  # Signals are raised again to trigger handling in main process
  logentry = ['%s\nUnhandled error at %s' % (
      '-'*60,
      time.strftime(
        '%Y-%m-%dT%H:%M:%SZ',time.gmtime(time.time())
      ),
    )]
  logentry.append('LDAPSession instance: %s' % repr(ls))
  # Log all environment vars
  env_vars = env.keys();env_vars.sort()
  for v in env_vars:
    logentry.append('%s: "%s"' % (v,env[v]))
  logentry.append(''.join(traceback.format_exception(exc_obj,exc_value,exc_traceback,20)))
  # Write the log entry to errf file object
  errf.write(os.linesep.join(logentry))
  # Avoid memory leaks
  exc_obj=None;exc_value=None;exc_traceback=None
  del exc_obj;del exc_value;del exc_traceback


########################################################################
# Initialize some constants
########################################################################

ldap._trace_level=w2lapp.cnf.misc.ldap_trace_level
ldap.set_option(ldap.OPT_DEBUG_LEVEL,w2lapp.cnf.misc.ldap_opt_debug_level)
ldap.set_option(ldap.OPT_RESTART,0)
ldap.set_option(ldap.OPT_DEREF,0)
ldap.set_option(ldap.OPT_REFERRALS,0)

startUpTime = time.time()
